from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CustomFieldType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PICKER: _ClassVar[CustomFieldType]
PICKER: CustomFieldType

class CustomFieldId(_message.Message):
    __slots__ = ("parts",)
    PARTS_FIELD_NUMBER: _ClassVar[int]
    parts: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parts: _Optional[_Iterable[str]] = ...) -> None: ...

class CustomFieldApiId(_message.Message):
    __slots__ = ("key",)
    class KeyEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: _containers.ScalarMap[str, str]
    def __init__(self, key: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CustomField(_message.Message):
    __slots__ = ("id", "apiId", "name", "fullyQualifiedName", "customFieldType", "allowedPickerValues")
    ID_FIELD_NUMBER: _ClassVar[int]
    APIID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FULLYQUALIFIEDNAME_FIELD_NUMBER: _ClassVar[int]
    CUSTOMFIELDTYPE_FIELD_NUMBER: _ClassVar[int]
    ALLOWEDPICKERVALUES_FIELD_NUMBER: _ClassVar[int]
    id: CustomFieldId
    apiId: CustomFieldApiId
    name: str
    fullyQualifiedName: str
    customFieldType: CustomFieldType
    allowedPickerValues: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[_Union[CustomFieldId, _Mapping]] = ..., apiId: _Optional[_Union[CustomFieldApiId, _Mapping]] = ..., name: _Optional[str] = ..., fullyQualifiedName: _Optional[str] = ..., customFieldType: _Optional[_Union[CustomFieldType, str]] = ..., allowedPickerValues: _Optional[_Iterable[str]] = ...) -> None: ...

class CustomFieldPickerValue(_message.Message):
    __slots__ = ("customFieldId", "value")
    CUSTOMFIELDID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    customFieldId: CustomFieldId
    value: str
    def __init__(self, customFieldId: _Optional[_Union[CustomFieldId, _Mapping]] = ..., value: _Optional[str] = ...) -> None: ...

class CustomFieldLink(_message.Message):
    __slots__ = ("schemaId", "tableId", "columnId", "pickerValue")
    SCHEMAID_FIELD_NUMBER: _ClassVar[int]
    TABLEID_FIELD_NUMBER: _ClassVar[int]
    COLUMNID_FIELD_NUMBER: _ClassVar[int]
    PICKERVALUE_FIELD_NUMBER: _ClassVar[int]
    schemaId: _mde_objects_pb2.SchemaId
    tableId: _mde_objects_pb2.TableId
    columnId: _mde_objects_pb2.ColumnId
    pickerValue: CustomFieldPickerValue
    def __init__(self, schemaId: _Optional[_Union[_mde_objects_pb2.SchemaId, _Mapping]] = ..., tableId: _Optional[_Union[_mde_objects_pb2.TableId, _Mapping]] = ..., columnId: _Optional[_Union[_mde_objects_pb2.ColumnId, _Mapping]] = ..., pickerValue: _Optional[_Union[CustomFieldPickerValue, _Mapping]] = ...) -> None: ...

class CustomFieldSyncValue(_message.Message):
    __slots__ = ("vString",)
    VSTRING_FIELD_NUMBER: _ClassVar[int]
    vString: str
    def __init__(self, vString: _Optional[str] = ...) -> None: ...

class CustomFieldValueUpdate(_message.Message):
    __slots__ = ("schemaApiId", "tableApiId", "columnApiId", "customFieldApiId", "customFieldType", "newValue")
    SCHEMAAPIID_FIELD_NUMBER: _ClassVar[int]
    TABLEAPIID_FIELD_NUMBER: _ClassVar[int]
    COLUMNAPIID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMFIELDAPIID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMFIELDTYPE_FIELD_NUMBER: _ClassVar[int]
    NEWVALUE_FIELD_NUMBER: _ClassVar[int]
    schemaApiId: _mde_objects_pb2.SchemaApiId
    tableApiId: _mde_objects_pb2.TableApiId
    columnApiId: _mde_objects_pb2.ColumnApiId
    customFieldApiId: CustomFieldApiId
    customFieldType: CustomFieldType
    newValue: CustomFieldSyncValue
    def __init__(self, schemaApiId: _Optional[_Union[_mde_objects_pb2.SchemaApiId, _Mapping]] = ..., tableApiId: _Optional[_Union[_mde_objects_pb2.TableApiId, _Mapping]] = ..., columnApiId: _Optional[_Union[_mde_objects_pb2.ColumnApiId, _Mapping]] = ..., customFieldApiId: _Optional[_Union[CustomFieldApiId, _Mapping]] = ..., customFieldType: _Optional[_Union[CustomFieldType, str]] = ..., newValue: _Optional[_Union[CustomFieldSyncValue, _Mapping]] = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from queryservice_client.protobuf.common import verify_pb2 as _verify_pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as _mde_pb2
from queryservice_client.protobuf.rdbms import profiling_pb2 as _profiling_pb2
from queryservice_client.protobuf.rdbms import qle_pb2 as _qle_pb2
from queryservice_client.protobuf.rdbms import query_pb2 as _query_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/profiling.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15rdbms/profiling.proto\x12\x0frdbms.profiling\x1a\x11\x63ommon/auth.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x17rdbms/mde_objects.proto\"\xae\x01\n\x15TableProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x34\n\rtableRequests\x18\x02 \x03(\x0b\x32\x1d.rdbms.profiling.TableRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x04 \x01(\t\"\x81\x02\n\x0cTableRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\x06schema\x18\x03 \x01(\tB\x02\x18\x01\x12\x16\n\x0epopulationSize\x18\x04 \x01(\r\x12\x12\n\nsampleSize\x18\x05 \x01(\r\x12\x31\n\x10sensitiveColumns\x18\x07 \x03(\x0b\x32\x17.rdbms.profiling.Column\x12(\n\x07\x63olumns\x18\x08 \x03(\x0b\x32\x17.rdbms.profiling.Column\x12\x0f\n\x07timeout\x18\t \x01(\r\x12\x13\n\x0bschema_name\x18\n \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x0b \x01(\t\"U\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x04\x12\x31\n\ncolumnType\x18\x04 \x01(\x0b\x32\x1d.rdbms.mde_objects.ColumnType\"\xcb\x01\n\x16TableProfilingResponse\x12\n\n\x02id\x18\x01 \x01(\x04\x12(\n\nrowSamples\x18\x02 \x03(\x0b\x32\x14.rdbms.profiling.Row\x12\x1b\n\x13numberOfRowsSampled\x18\x03 \x01(\r\x12\x14\n\x0csecondsTaken\x18\x04 \x01(\r\x12\x0f\n\x07hasMore\x18\x05 \x01(\x08\x12\x37\n\x0f\x63olumnSummaries\x18\x06 \x03(\x0b\x32\x1e.rdbms.profiling.ColumnSummary\"\x15\n\x03Row\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xc3\x01\n\rColumnSummary\x12\x39\n\x0c\x64istribution\x18\x01 \x03(\x0b\x32#.rdbms.profiling.ColumnDistribution\x12\x15\n\rnumberOfNulls\x18\x02 \x01(\r\x12\x1c\n\x14numberOfUniqueValues\x18\x03 \x01(\r\x12\x19\n\x11numberOfAllValues\x18\x04 \x01(\r\x12\'\n\x06\x63olumn\x18\x05 \x01(\x0b\x32\x17.rdbms.profiling.Column\"2\n\x12\x43olumnDistribution\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xba\x01\n\x1b\x43ustomTableProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12:\n\rtableRequests\x18\x02 \x03(\x0b\x32#.rdbms.profiling.CustomTableRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x04 \x01(\t\"V\n\x12\x43ustomTableRequest\x12.\n\x07request\x18\x01 \x01(\x0b\x32\x1d.rdbms.profiling.TableRequest\x12\x10\n\x08override\x18\x02 \x01(\t\"\x82\x01\n\x1c\x43ustomTableProfilingResponse\x12\x39\n\x08response\x18\x01 \x01(\x0b\x32\'.rdbms.profiling.TableProfilingResponse\x12\'\n\x06schema\x18\x02 \x03(\x0b\x32\x17.rdbms.profiling.Column\"\xaa\x01\n\x16\x43olumnProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12/\n\x07request\x18\x02 \x01(\x0b\x32\x1e.rdbms.profiling.ColumnRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x04 \x01(\t\"\xce\x01\n\rColumnRequest\x12\x12\n\x06schema\x18\x01 \x01(\tB\x02\x18\x01\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x03 \x01(\t\x12\x12\n\nsampleSize\x18\x04 \x01(\r\x12\x0f\n\x07timeout\x18\x05 \x01(\r\x12:\n\x04type\x18\x06 \x01(\x0e\x32,.rdbms.mde_objects.ColumnType.NormalizedType\x12\x13\n\x0bschema_name\x18\x07 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x08 \x01(\t\"\xa2\x01\n\x17\x43olumnProfilingResponse\x12;\n\x0c\x64istribution\x18\x01 \x01(\x0b\x32#.rdbms.profiling.ColumnDistributionH\x00\x12>\n\x05\x66inal\x18\x03 \x01(\x0b\x32-.rdbms.profiling.ColumnProfilingFinalResponseH\x00\x42\n\n\x08response\"u\n\x1c\x43olumnProfilingFinalResponse\x12.\n\nstatistics\x18\x02 \x03(\x0b\x32\x1a.rdbms.profiling.Statistic\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x12\x14\n\x0csecondsTaken\x18\x05 \x01(\r\"(\n\tStatistic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xed\x01\n\x1c\x43ustomColumnProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12/\n\x07request\x18\x02 \x01(\x0b\x32\x1e.rdbms.profiling.ColumnRequest\x12;\n\x08override\x18\x03 \x01(\x0b\x32).rdbms.profiling.ColumnStatisticsOverride\x12\x18\n\x04\x61uth\x18\x04 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x05 \x01(\t\"\x7f\n\x18\x43olumnStatisticsOverride\x12\x11\n\x07literal\x18\x01 \x01(\tH\x00\x12G\n\ttemplated\x18\x02 \x01(\x0b\x32\x32.rdbms.profiling.TemplatedColumnStatisticsOverrideH\x00\x42\x07\n\x05query\"\xa7\x01\n!TemplatedColumnStatisticsOverride\x12\x17\n\x0fnumericTemplate\x18\x01 \x01(\t\x12\x1a\n\x12nonNumericTemplate\x18\x02 \x01(\t\x12\x19\n\x11\x63olumnPlaceholder\x18\x03 \x01(\t\x12\x18\n\x10tablePlaceholder\x18\x04 \x01(\t\x12\x18\n\x10limitPlaceholder\x18\x05 \x01(\tB@\n alation.sdk.rdbms.grpc.profilingB\tProfilingP\x01Z\x0frdbms/profilingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.profiling_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n alation.sdk.rdbms.grpc.profilingB\tProfilingP\001Z\017rdbms/profiling'
  _globals['_TABLEREQUEST'].fields_by_name['schema']._options = None
  _globals['_TABLEREQUEST'].fields_by_name['schema']._serialized_options = b'\030\001'
  _globals['_COLUMNREQUEST'].fields_by_name['schema']._options = None
  _globals['_COLUMNREQUEST'].fields_by_name['schema']._serialized_options = b'\030\001'
  _globals['_TABLEPROFILINGREQUEST']._serialized_start=115
  _globals['_TABLEPROFILINGREQUEST']._serialized_end=289
  _globals['_TABLEREQUEST']._serialized_start=292
  _globals['_TABLEREQUEST']._serialized_end=549
  _globals['_COLUMN']._serialized_start=551
  _globals['_COLUMN']._serialized_end=636
  _globals['_TABLEPROFILINGRESPONSE']._serialized_start=639
  _globals['_TABLEPROFILINGRESPONSE']._serialized_end=842
  _globals['_ROW']._serialized_start=844
  _globals['_ROW']._serialized_end=865
  _globals['_COLUMNSUMMARY']._serialized_start=868
  _globals['_COLUMNSUMMARY']._serialized_end=1063
  _globals['_COLUMNDISTRIBUTION']._serialized_start=1065
  _globals['_COLUMNDISTRIBUTION']._serialized_end=1115
  _globals['_CUSTOMTABLEPROFILINGREQUEST']._serialized_start=1118
  _globals['_CUSTOMTABLEPROFILINGREQUEST']._serialized_end=1304
  _globals['_CUSTOMTABLEREQUEST']._serialized_start=1306
  _globals['_CUSTOMTABLEREQUEST']._serialized_end=1392
  _globals['_CUSTOMTABLEPROFILINGRESPONSE']._serialized_start=1395
  _globals['_CUSTOMTABLEPROFILINGRESPONSE']._serialized_end=1525
  _globals['_COLUMNPROFILINGREQUEST']._serialized_start=1528
  _globals['_COLUMNPROFILINGREQUEST']._serialized_end=1698
  _globals['_COLUMNREQUEST']._serialized_start=1701
  _globals['_COLUMNREQUEST']._serialized_end=1907
  _globals['_COLUMNPROFILINGRESPONSE']._serialized_start=1910
  _globals['_COLUMNPROFILINGRESPONSE']._serialized_end=2072
  _globals['_COLUMNPROFILINGFINALRESPONSE']._serialized_start=2074
  _globals['_COLUMNPROFILINGFINALRESPONSE']._serialized_end=2191
  _globals['_STATISTIC']._serialized_start=2193
  _globals['_STATISTIC']._serialized_end=2233
  _globals['_CUSTOMCOLUMNPROFILINGREQUEST']._serialized_start=2236
  _globals['_CUSTOMCOLUMNPROFILINGREQUEST']._serialized_end=2473
  _globals['_COLUMNSTATISTICSOVERRIDE']._serialized_start=2475
  _globals['_COLUMNSTATISTICSOVERRIDE']._serialized_end=2602
  _globals['_TEMPLATEDCOLUMNSTATISTICSOVERRIDE']._serialized_start=2605
  _globals['_TEMPLATEDCOLUMNSTATISTICSOVERRIDE']._serialized_end=2772
# @@protoc_insertion_point(module_scope)



import logging
from typing import Optional
from queryservice_client.queryclient import QueryClient
from queryservice_client.stream.segments.statement import Statement

logger = logging.getLogger(__name__)

class QuerySession:
    def __init__(self, session_id: int, client: QueryClient):
        self.session_id = session_id
        self.client = client

    def query(self, query: str, limit: Optional[int] = None, timeout_in_seconds: Optional[int] = None) -> Statement:
        logger.info(f"Query timeout set to: {timeout_in_seconds} seconds")
        return self.client.query(self.session_id, query, limit, timeout_in_seconds)

    def cancel_query(self):
        self.client.cancel_query(self.session_id)

    def close(self):
        self.client.end_session(self.session_id)


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PolicyId(_message.Message):
    __slots__ = ("parts",)
    PARTS_FIELD_NUMBER: _ClassVar[int]
    parts: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parts: _Optional[_Iterable[str]] = ...) -> None: ...

class PolicyApiId(_message.Message):
    __slots__ = ("key",)
    class KeyEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: _containers.ScalarMap[str, str]
    def __init__(self, key: _Optional[_Mapping[str, str]] = ...) -> None: ...

class SQLDefinition(_message.Message):
    __slots__ = ("sql", "arguments")
    SQL_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    sql: str
    arguments: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, sql: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...

class Policy(_message.Message):
    __slots__ = ("id", "apiId", "name", "policyType", "owner", "tsCreated", "sqlDefinition")
    class PolicyType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DATA_MASK: _ClassVar[Policy.PolicyType]
        ROW_ACCESS: _ClassVar[Policy.PolicyType]
    DATA_MASK: Policy.PolicyType
    ROW_ACCESS: Policy.PolicyType
    ID_FIELD_NUMBER: _ClassVar[int]
    APIID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    POLICYTYPE_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    TSCREATED_FIELD_NUMBER: _ClassVar[int]
    SQLDEFINITION_FIELD_NUMBER: _ClassVar[int]
    id: PolicyId
    apiId: PolicyApiId
    name: str
    policyType: Policy.PolicyType
    owner: str
    tsCreated: _timestamp_pb2.Timestamp
    sqlDefinition: SQLDefinition
    def __init__(self, id: _Optional[_Union[PolicyId, _Mapping]] = ..., apiId: _Optional[_Union[PolicyApiId, _Mapping]] = ..., name: _Optional[str] = ..., policyType: _Optional[_Union[Policy.PolicyType, str]] = ..., owner: _Optional[str] = ..., tsCreated: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., sqlDefinition: _Optional[_Union[SQLDefinition, _Mapping]] = ...) -> None: ...

class TableLink(_message.Message):
    __slots__ = ("pid", "tableId")
    PID_FIELD_NUMBER: _ClassVar[int]
    TABLEID_FIELD_NUMBER: _ClassVar[int]
    pid: PolicyId
    tableId: _mde_objects_pb2.TableId
    def __init__(self, pid: _Optional[_Union[PolicyId, _Mapping]] = ..., tableId: _Optional[_Union[_mde_objects_pb2.TableId, _Mapping]] = ...) -> None: ...

class ColumnLink(_message.Message):
    __slots__ = ("pid", "columnId")
    PID_FIELD_NUMBER: _ClassVar[int]
    COLUMNID_FIELD_NUMBER: _ClassVar[int]
    pid: PolicyId
    columnId: _mde_objects_pb2.ColumnId
    def __init__(self, pid: _Optional[_Union[PolicyId, _Mapping]] = ..., columnId: _Optional[_Union[_mde_objects_pb2.ColumnId, _Mapping]] = ...) -> None: ...

class PolicyObjectApiId(_message.Message):
    __slots__ = ("tableApiId", "columnApiId")
    TABLEAPIID_FIELD_NUMBER: _ClassVar[int]
    COLUMNAPIID_FIELD_NUMBER: _ClassVar[int]
    tableApiId: _mde_objects_pb2.TableApiId
    columnApiId: _mde_objects_pb2.ColumnApiId
    def __init__(self, tableApiId: _Optional[_Union[_mde_objects_pb2.TableApiId, _Mapping]] = ..., columnApiId: _Optional[_Union[_mde_objects_pb2.ColumnApiId, _Mapping]] = ...) -> None: ...

class PolicyArgument(_message.Message):
    __slots__ = ("argument", "columnId")
    ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    COLUMNID_FIELD_NUMBER: _ClassVar[int]
    argument: str
    columnId: _mde_objects_pb2.ColumnId
    def __init__(self, argument: _Optional[str] = ..., columnId: _Optional[_Union[_mde_objects_pb2.ColumnId, _Mapping]] = ...) -> None: ...

class PolicyObjectSyncValue(_message.Message):
    __slots__ = ("policyObjectApiId", "policyArguments")
    POLICYOBJECTAPIID_FIELD_NUMBER: _ClassVar[int]
    POLICYARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    policyObjectApiId: PolicyObjectApiId
    policyArguments: _containers.RepeatedCompositeFieldContainer[PolicyArgument]
    def __init__(self, policyObjectApiId: _Optional[_Union[PolicyObjectApiId, _Mapping]] = ..., policyArguments: _Optional[_Iterable[_Union[PolicyArgument, _Mapping]]] = ...) -> None: ...



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from asset import mde_objects_pb2 as _mde_objects_pb2
from asset import filter_extraction_pb2 as _filter_extraction_pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as _extraction_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MetadataExtractionRequest(_message.Message):
    __slots__ = ("configuration", "filter", "isInclusionFilter")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ISINCLUSIONFILTER_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    filter: _containers.RepeatedCompositeFieldContainer[_filter_extraction_pb2.FilterExtractionResponse]
    isInclusionFilter: bool
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., filter: _Optional[_Iterable[_Union[_filter_extraction_pb2.FilterExtractionResponse, _Mapping]]] = ..., isInclusionFilter: bool = ...) -> None: ...

class MetadataExtractionResponse(_message.Message):
    __slots__ = ("asset", "error", "extractionProgress", "dqRuleAndValue")
    ASSET_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EXTRACTIONPROGRESS_FIELD_NUMBER: _ClassVar[int]
    DQRULEANDVALUE_FIELD_NUMBER: _ClassVar[int]
    asset: _mde_objects_pb2.Asset
    error: _job_error_pb2.Error
    extractionProgress: _extraction_objects_pb2.ExtractionProgress
    dqRuleAndValue: _mde_objects_pb2.DQRuleAndValue
    def __init__(self, asset: _Optional[_Union[_mde_objects_pb2.Asset, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ..., extractionProgress: _Optional[_Union[_extraction_objects_pb2.ExtractionProgress, _Mapping]] = ..., dqRuleAndValue: _Optional[_Union[_mde_objects_pb2.DQRuleAndValue, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/error.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63ommon/error.proto\x12\x05\x65rror\"\x18\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\tB?\n\x1d\x61lation.sdk.grpc.common.errorB\x0e\x43onnectorErrorP\x01Z\x0c\x63ommon/errorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.error_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035alation.sdk.grpc.common.errorB\016ConnectorErrorP\001Z\014common/error'
  _globals['_ERROR']._serialized_start=29
  _globals['_ERROR']._serialized_end=53
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policy/policy_sync.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from policy import policy_objects_pb2 as policy_dot_policy__objects__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import error_pb2 as common_dot_error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18policy/policy_sync.proto\x12\x10ocf.policy.rdbms\x1a\x1bpolicy/policy_objects.proto\x1a\x11\x63ommon/auth.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x12\x63ommon/error.proto\"\xc1\x01\n\x12PolicySyncResponse\x12\x39\n\ttableLink\x18\x01 \x01(\x0b\x32$.ocf.policy.policy_objects.TableLinkH\x00\x12;\n\ncolumnLink\x18\x02 \x01(\x0b\x32%.ocf.policy.policy_objects.ColumnLinkH\x00\x12\x1d\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x0c.error.ErrorH\x00\x42\x14\n\x12PolicySyncResponse\"\xf2\x01\n\x11PolicySyncRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x18\n\x04\x61uth\x18\x02 \x01(\x0b\x32\n.auth.Auth\x12;\n\x0bpolicyApiId\x18\x03 \x01(\x0b\x32&.ocf.policy.policy_objects.PolicyApiId\x12P\n\x16policyObjectSyncValues\x18\x04 \x03(\x0b\x32\x30.ocf.policy.policy_objects.PolicyObjectSyncValue2\xd6\x01\n\x0fRdbmsPolicySync\x12`\n\x0fPolicySyncApply\x12#.ocf.policy.rdbms.PolicySyncRequest\x1a$.ocf.policy.rdbms.PolicySyncResponse\"\x00\x30\x01\x12\x61\n\x10PolicySyncRevoke\x12#.ocf.policy.rdbms.PolicySyncRequest\x1a$.ocf.policy.rdbms.PolicySyncResponse\"\x00\x30\x01\x42-\n\x1b\x61lation.sdk.ocf.policy.grpcB\x0cMetadataSyncP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy.policy_sync_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.policy.grpcB\014MetadataSyncP\001'
  _globals['_POLICYSYNCRESPONSE']._serialized_start=143
  _globals['_POLICYSYNCRESPONSE']._serialized_end=336
  _globals['_POLICYSYNCREQUEST']._serialized_start=339
  _globals['_POLICYSYNCREQUEST']._serialized_end=581
  _globals['_RDBMSPOLICYSYNC']._serialized_start=584
  _globals['_RDBMSPOLICYSYNC']._serialized_end=798
# @@protoc_insertion_point(module_scope)
